"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Browser = exports.createBrowser = void 0;
const browser_1 = require("./browser");
Object.defineProperty(exports, "Browser", { enumerable: true, get: function () { return browser_1.Browser; } });
const clustered_1 = require("./clustered");
const reusable_1 = require("./reusable");
function createBrowser(config, log, metrics) {
    if (config.mode === 'clustered') {
        log.info('using clustered browser', 'mode', config.clustering.mode, 'maxConcurrency', config.clustering.maxConcurrency, 'timeout', config.clustering.timeout);
        return new clustered_1.ClusteredBrowser(config, log, metrics);
    }
    if (config.mode === 'reusable') {
        log.info('using reusable browser');
        return new reusable_1.ReusableBrowser(config, log, metrics);
    }
    if (!config.args.includes('--disable-gpu')) {
        log.warn('using default mode without the --disable-gpu flag is not recommended as it can cause Puppeteer newPage function to freeze, leaving browsers open');
    }
    return new browser_1.Browser(config, log, metrics);
}
exports.createBrowser = createBrowser;
//# sourceMappingURL=index.js.map