"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.populateServiceConfigFromEnv = exports.defaultServiceConfig = void 0;
const rendering_1 = require("../config/rendering");
exports.defaultServiceConfig = {
    service: {
        host: undefined,
        port: 8081,
        protocol: 'http',
        metrics: {
            enabled: false,
            collectDefaultMetrics: true,
            requestDurationBuckets: [0.5, 1, 3, 5, 7, 10, 20, 30, 60],
        },
        logging: {
            level: 'info',
            console: {
                json: true,
                colorize: false,
            },
        },
        security: {
            authToken: '-',
        },
    },
    rendering: rendering_1.defaultRenderingConfig,
};
function populateServiceConfigFromEnv(config, env) {
    if (env['HTTP_HOST']) {
        config.service.host = env['HTTP_HOST'];
    }
    if (env['HTTP_PORT']) {
        config.service.port = parseInt(env['HTTP_PORT'], 10);
    }
    if (env['HTTP_PROTOCOL']) {
        config.service.protocol = env['HTTP_PROTOCOL'];
    }
    if (env['HTTP_CERT_FILE']) {
        config.service.certFile = env['HTTP_CERT_FILE'];
    }
    if (env['HTTP_CERT_KEY']) {
        config.service.certKey = env['HTTP_CERT_KEY'];
    }
    if (env['HTTP_MIN_TLS_VERSION']) {
        config.service.minTLSVersion = env['HTTP_MIN_TLS_VERSION'];
    }
    if (env['AUTH_TOKEN']) {
        const authToken = env['AUTH_TOKEN'];
        config.service.security.authToken = authToken.includes(' ') ? authToken.split(' ') : authToken;
    }
    if (env['LOG_LEVEL']) {
        config.service.logging.level = env['LOG_LEVEL'];
    }
    if (env['ENABLE_METRICS']) {
        config.service.metrics.enabled = env['ENABLE_METRICS'] === 'true';
    }
    (0, rendering_1.populateRenderingConfigFromEnv)(config.rendering, env, rendering_1.Mode.Server);
}
exports.populateServiceConfigFromEnv = populateServiceConfigFromEnv;
//# sourceMappingURL=config.js.map